aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--README.md2
-rw-r--r--lib/ast.js2
-rw-r--r--lib/output.js28
-rw-r--r--test/compress/loops.js16
-rw-r--r--test/input/issue-1482/braces.js (renamed from test/input/issue-1482/bracketize.js)0
-rw-r--r--test/mocha/cli.js6
-rw-r--r--test/mocha/comment.js2
-rw-r--r--test/mocha/release.js2
-rw-r--r--test/mozilla-ast.js2
-rw-r--r--test/ufuzz.js2
-rw-r--r--test/ufuzz.json2
11 files changed, 32 insertions, 32 deletions
diff --git a/README.md b/README.md
index ee35b7d8..35859115 100644
--- a/README.md
+++ b/README.md
@@ -824,7 +824,7 @@ can pass additional arguments that control the code output:
when you want to generate minified code, in order to specify additional
arguments, so you can use `-b beautify=false` to override it.
-- `bracketize` (default `false`) -- always insert brackets in `if`, `for`,
+- `braces` (default `false`) -- always insert braces in `if`, `for`,
`do`, `while` or `with` statements, even if their body is a single
statement.
diff --git a/lib/ast.js b/lib/ast.js
index 9b88b088..a23dece6 100644
--- a/lib/ast.js
+++ b/lib/ast.js
@@ -165,7 +165,7 @@ function walk_body(node, visitor) {
};
var AST_Block = DEFNODE("Block", "body", {
- $documentation: "A body of statements (usually bracketed)",
+ $documentation: "A body of statements (usually braced)",
$propdoc: {
body: "[AST_Statement*] an array of statements"
},
diff --git a/test/compress/loops.js b/test/compress/loops.js
index 625b552d..2dd29256 100644
--- a/test/compress/loops.js
+++ b/test/compress/loops.js
@@ -294,10 +294,10 @@ issue_186_beautify_ie8: {
]
}
-issue_186_bracketize: {
+issue_186_braces: {
beautify = {
beautify: false,
- bracketize: true,
+ braces: true,
ie8: false,
}
input: {
@@ -314,10 +314,10 @@ issue_186_bracketize: {
expect_exact: 'var x=3;if(foo()){do{do{alert(x)}while(--x)}while(x)}else{bar()}'
}
-issue_186_bracketize_ie8: {
+issue_186_braces_ie8: {
beautify = {
beautify: false,
- bracketize: true,
+ braces: true,
ie8: true,
}
input: {
@@ -334,10 +334,10 @@ issue_186_bracketize_ie8: {
expect_exact: 'var x=3;if(foo()){do{do{alert(x)}while(--x)}while(x)}else{bar()}'
}
-issue_186_beautify_bracketize: {
+issue_186_beautify_braces: {
beautify = {
beautify: true,
- bracketize: true,
+ braces: true,
ie8: false,
}
input: {
@@ -366,10 +366,10 @@ issue_186_beautify_bracketize: {
]
}
-issue_186_beautify_bracketize_ie8: {
+issue_186_beautify_braces_ie8: {
beautify = {
beautify: true,
- bracketize: true,
+ braces: true,
ie8: true,
}
input: {
diff --git a/test/input/issue-1482/bracketize.js b/test/input/issue-1482/braces.js
index 2c2b103c..2c2b103c 100644
--- a/test/input/issue-1482/bracketize.js
+++ b/test/input/issue-1482/braces.js
diff --git a/test/mocha/cli.js b/test/mocha/cli.js
index 671d700e..10f0465a 100644
--- a/test/mocha/cli.js
+++ b/test/mocha/cli.js
@@ -164,13 +164,13 @@ describe("bin/uglifyjs", function () {
done();
});
});
- it("Should work with `--beautify bracketize`", function (done) {
- var command = uglifyjscmd + ' test/input/issue-1482/input.js -b bracketize';
+ it("Should work with `--beautify braces`", function (done) {
+ var command = uglifyjscmd + ' test/input/issue-1482/input.js -b braces';
exec(command, function (err, stdout) {
if (err) throw err;
- assert.strictEqual(stdout, read("test/input/issue-1482/bracketize.js"));
+ assert.strictEqual(stdout, read("test/input/issue-1482/braces.js"));
done();
});
});
diff --git a/test/mocha/comment.js b/test/mocha/comment.js
index 74ae962c..9fc50470 100644
--- a/test/mocha/comment.js
+++ b/test/mocha/comment.js
@@ -139,7 +139,7 @@ describe("Comment", function() {
assert.strictEqual(result.code, code);
});
- it("Should retain comments within brackets", function() {
+ it("Should retain comments within braces", function() {
var code = [
"{/* foo */}",
"a({/* foo */});",
diff --git a/test/mocha/release.js b/test/mocha/release.js
index 063d0fc7..f911b009 100644
--- a/test/mocha/release.js
+++ b/test/mocha/release.js
@@ -17,7 +17,7 @@ describe("test/benchmark.js", function() {
this.timeout(10 * 60 * 1000);
[
"-b",
- "-b bracketize",
+ "-b braces",
"-m",
"-mc passes=3",
"-mc passes=3,toplevel",
diff --git a/test/mozilla-ast.js b/test/mozilla-ast.js
index b8026de5..4f17c892 100644
--- a/test/mozilla-ast.js
+++ b/test/mozilla-ast.js
@@ -11,7 +11,7 @@ function try_beautify(code) {
mangle: false,
output: {
beautify: true,
- bracketize: true
+ braces: true
}
});
if (beautified.error) {
diff --git a/test/ufuzz.js b/test/ufuzz.js
index f717f00b..4061e8d7 100644
--- a/test/ufuzz.js
+++ b/test/ufuzz.js
@@ -975,7 +975,7 @@ function try_beautify(code, result, printfn) {
mangle: false,
output: {
beautify: true,
- bracketize: true,
+ braces: true,
},
});
if (beautified.error) {
diff --git a/test/ufuzz.json b/test/ufuzz.json
index 5ccd96e0..969ae43b 100644
--- a/test/ufuzz.json
+++ b/test/ufuzz.json
@@ -4,7 +4,7 @@
"mangle": false,
"output": {
"beautify": true,
- "bracketize": true
+ "braces": true
},
"rename": true
},
diff --git a/lib/output.js b/lib/output.js
index 0aaec42b..6c1d61a3 100644
--- a/lib/output.js
+++ b/lib/output.js
@@ -56,7 +56,7 @@ function OutputStream(options) {
options = defaults(options, {
ascii_only : false,
beautify : false,
- bracketize : false,
+ braces : false,
comments : false,
ie8 : false,
indent_level : 4,
@@ -886,22 +886,22 @@ function OutputStream(options) {
self.body.print(output);
output.semicolon();
});
- function print_bracketed_empty(self, output) {
+ function print_braced_empty(self, output) {
output.print("{");
output.with_indent(output.next_indent(), function() {
output.append_comments(self, true);
});
output.print("}");
}
- function print_bracketed(self, output, allow_directives) {
+ function print_braced(self, output, allow_directives) {
if (self.body.length > 0) {
output.with_block(function() {
display_body(self.body, false, output, allow_directives);
});
- } else print_bracketed_empty(self, output);
+ } else print_braced_empty(self, output);
};
DEFPRINT(AST_BlockStatement, function(self, output){
- print_bracketed(self, output);
+ print_braced(self, output);
});
DEFPRINT(AST_EmptyStatement, function(self, output){
output.semicolon();
@@ -996,7 +996,7 @@ function OutputStream(options) {
});
});
output.space();
- print_bracketed(self, output, true);
+ print_braced(self, output, true);
});
DEFPRINT(AST_Lambda, function(self, output){
self._do_print(output);
@@ -1037,7 +1037,7 @@ function OutputStream(options) {
/* -----[ if ]----- */
function make_then(self, output) {
var b = self.body;
- if (output.option("bracketize")
+ if (output.option("braces")
|| output.option("ie8") && b instanceof AST_Do)
return make_block(b, output);
// The squeezer replaces "block"-s that contain only a single
@@ -1046,7 +1046,7 @@ function OutputStream(options) {
// IF having an ELSE clause where the THEN clause ends in an
// IF *without* an ELSE block (then the outer ELSE would refer
// to the inner IF). This function checks for this case and
// adds the block brackets if needed.
if (!b) return output.force_semicolon();
while (true) {
if (b instanceof AST_If) {
@@ -1093,7 +1093,7 @@ function OutputStream(options) {
});
output.space();
var last = self.body.length - 1;
- if (last < 0) print_bracketed_empty(self, output);
+ if (last < 0) print_braced_empty(self, output);
else output.with_block(function(){
self.body.forEach(function(branch, i){
output.indent(true);
@@ -1127,7 +1127,7 @@ function OutputStream(options) {
DEFPRINT(AST_Try, function(self, output){
output.print("try");
output.space();
- print_bracketed(self, output);
+ print_braced(self, output);
if (self.bcatch) {
output.space();
self.bcatch.print(output);
@@ -1144,12 +1144,12 @@ function OutputStream(options) {
self.argname.print(output);
});
output.space();
- print_bracketed(self, output);
+ print_braced(self, output);
});
DEFPRINT(AST_Finally, function(self, output){
output.print("finally");
output.space();
- print_bracketed(self, output);
+ print_braced(self, output);
});
/* -----[ var/const ]----- */
@@ -1348,7 +1348,7 @@ function OutputStream(options) {
});
output.newline();
});
- else print_bracketed_empty(self, output);
+ else print_braced_empty(self, output);
});
function print_property_name(key, quote, output) {
@@ -1420,7 +1420,7 @@ function OutputStream(options) {
});
function force_statement(stat, output) {
- if (output.option("bracketize")) {
+ if (output.option("braces")) {
make_block(stat, output);
} else {
if (!stat || stat instanceof AST_EmptyStatement)
@@ -1046,7 +1046,7 @@ function OutputStream(options) {
// IF *without* an ELSE block (then the outer ELSE would refer
// to the inner IF). This function checks for this case and
- // adds the block brackets if needed.
+ // adds the block braces if needed.
if (!b) return output.force_semicolon();
while (true) {